#
# spec file for package python-debtcollector
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-debtcollector
Version:        3.0.0
Release:        2.1
Summary:        A collection of Python deprecation patterns and strategies
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/debtcollector/latest/
Source0:        https://files.pythonhosted.org/packages/source/d/debtcollector/debtcollector-3.0.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-fixtures
BuildRequires:  python3-pbr
BuildRequires:  python3-python-subunit
BuildRequires:  python3-stestr
BuildRequires:  python3-wrapt >= 1.7.0
BuildArch:      noarch

%description
A collection of Python deprecation patterns and strategies that help
you collect your technical debt in a non-destructive manner. The goal
of this library is to provide well documented developer facing
deprecation patterns that start of with a basic set and can expand
into a larger set of patterns as time goes on. The desired output of
these patterns is to apply the warnings module to emit
DeprecationWarning or PendingDeprecationWarning or similar derivative
to developers using libraries (or potentially applications) about
future deprecations.

%package -n python3-debtcollector
Summary:        A collection of Python deprecation patterns and strategies
Requires:       python3-importlib-metadata
Requires:       python3-pbr
Requires:       python3-wrapt >= 1.7.0

%description -n python3-debtcollector
A collection of Python deprecation patterns and strategies that help
you collect your technical debt in a non-destructive manner. The goal
of this library is to provide well documented developer facing
deprecation patterns that start of with a basic set and can expand
into a larger set of patterns as time goes on. The desired output of
these patterns is to apply the warnings module to emit
DeprecationWarning or PendingDeprecationWarning or similar derivative
to developers using libraries (or potentially applications) about
future deprecations.

This package contains the Python 3.x module.

%package -n python-debtcollector-doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-debtcollector-doc
A collection of Python deprecation patterns and strategies that help
you collect your technical debt in a non-destructive manner. The goal
of this library is to provide well documented developer facing
deprecation patterns that start of with a basic set and can expand
into a larger set of patterns as time goes on. The desired output of
these patterns is to apply the warnings module to emit
DeprecationWarning or PendingDeprecationWarning or similar derivative
to developers using libraries (or potentially applications) about
future deprecations.

This package contains documentation in HTML format.

%prep
%autosetup -p1 -n debtcollector-3.0.0
%py_req_cleanup

%build
%py3_build

# generate html doc
PBR_VERSION=3.0.0 %sphinx_build -b html doc/source doc/build/html
# remove the Sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
%{openstack_stestr_run}

%install
%py3_install

%files -n python3-debtcollector
%license LICENSE
%doc README.rst
%{python3_sitelib}/debtcollector
%{python3_sitelib}/debtcollector-*.egg-info

%files -n python-debtcollector-doc
%license LICENSE
%doc doc/build/html

%changelog
* Wed Jan 22 2025 Steve Kowalik <steven.kowalik@suse.com>
- Drop unneeded Requires on six, not needed since 2.5.0.
* Fri May 10 2024 cloud-devel@suse.de
- update to version 3.0.0
  - Remove unused babel.cfg
  - Update python classifier in setup.cfg
  - Bump hacking
  - Moves supported python runtimes from version 3.8 to 3.10
  - Drop python3.6/3.7 support in testing runtime
  - requirements: Remove unnecessary dependency
  - Add Python 3.8 and 3.9 to supported runtimes
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - coveragerc: Remove non-existent path
  - Update CI to use unversioned jobs template
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 2.5.0
  - Remove unnecessary 'coding' lines
  - requirements: Remove pbr
  - Restore reproducibility in docs
  - Remove references to Python 2 objects
  - Remove six
* Mon Nov 29 2021 cloud-devel@suse.de
- update to version 2.3.0
  - Use py3 as the default runtime for tox
  - Move flake8 as a pre-commit local target.
  - Remove lower-constraints remnants
  - Replace deprecated inspect.getargspec
  - Add Python3 wallaby unit tests
  - Adding pre-commit
  - Use TOX_CONSTRAINTS_FILE
  - Dropping lower constraints testing
  - remove unicode from code
  - Remove runtime dependency on pbr
  - setup.cfg: Replace dashes with underscores
  - Update master for stable/victoria
  - ignore reno generated artifacts
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.2.0
  - Switch to newer openstackdocstheme and reno versions
  - Stop to use the __future__ module.
  - Update lower-constraints versions
  - Update master for stable/ussuri
  - Switch to Victoria tests
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.0.1
  - Update hacking for Python3
  - Update master for stable/train
  - [ussuri][goal] Drop python 2.7 support and testing
  - Update the minversion parameter.
  - Move docs linting to pep8
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Thu Oct 17 2019 cloud-devel@suse.de
- update to version 1.22.0
  - OpenDev Migration Patch
  - add python 3.7 unit test job
  - Update master for stable/stein
  - Dropping the py35 testing
  - Replace git.openstack.org URLs with opendev.org URLs
  - Update Sphinx requirement
  - Add Python 3 Train unit tests
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.21.0
  - Use template for lower-constraints
  - Add release note link in README
  - add lib-forward-testing-python3 test job
  - Change openstack-dev to openstack-discuss
  - Update reno for stable/rocky
  - Don't quote {posargs} in tox.ini
  - Remove PyPI downloads
  - add python 3.6 unit test job
  - import zuul job settings from project-config
* Mon Oct  8 2018 cloud-devel@suse.de
- update to version 1.20.0
  - set default python to python3
  - fix tox python3 overrides
  - Update reno for stable/queens
  - pypy is not checked at gate
  - Trivial: Update pypi url to new url
  - Update links in README
  - Remove setting of version/release from releasenotes
  - remove obsolete tox environments
  - Switch to stestr
  - Updated from global requirements
  - add lower-constraints job
* Mon Sep  3 2018 dmueller@suse.com
- switch to stable/rocky template
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Thu Jan 18 2018 cloud-devel@suse.de
- update to version 1.19.0
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Tue Nov 21 2017 cloud-devel@suse.de
- update to version 1.18.0
  - Update reno for stable/pike
  - Updated from global requirements
* Thu Sep 28 2017 cloud-devel@suse.de
- update to version 1.17.1
  - Update .gitreview for stable/pike
  - Updated from global requirements
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.17.0
  - Remove testscenarios from test-requirements.txt
  - Do not require oslotest for testing
  - Update URLs in documents according to document migration
  - rearrange existing documentation to fit the new standard layout
  - Update reno for stable/ocata
  - Remove pbr warnerrors in favor of sphinx check
  - Updated from global requirements
  - switch from oslosphinx to openstackdocstheme
  - Python 3.4 support has been removed
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 1.11.0:
  - Remove discover from test-requirements
  - Trivial: Remove 'MANIFEST.in'
  - Fix a typo in comment
  - Typo fix for module debtcollector
  - Drop *openstack/common* in flake8 exclude list
  - Add Constraints support
  - Add reno for release notes management
  - Add tests for decorated argspec preservation
  - Show team and repo badges on README
  - Update homepage with developer documentation page
  - Fix renamed_kwarg to preserve argspec
  - Add Python 3.5 classifier and venv
  - Drop babel as requirement since its not used
  - Updated from global requirements
- Switch to spec template from openstack/rpm-packaging project
* Tue Nov 15 2016 dmueller@suse.com
- update to 1.8.0:
  * Drop *openstack/common* in flake8 exclude list
  * Remove discover from test-requirements
  * Add Python 3.5 classifier and venv
  * Drop babel as requirement since its not used
  * Fix renamed_kwarg to preserve argspec
  * Add tests for decorated argspec preservation
  * Updated from global requirements
* Mon Feb 15 2016 dmueller@suse.com
- update to 1.3.0:
  * Updated from global requirements
  * Add debug testenv in tox
  * Add updated_kwarg_default_value decorator
  * Allow replacing a keyword argument
  * Add 'removed_class' class decorator
  * py26/py33 are no longer supported by Infra's CI
  * Add removals.remove note about metaclasses
  * Updated from global requirements
  * Update get_class_name from olso.utils
  * Remove Python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Add 'moved_read_only_property' descriptor
  * Add ability to disable warnings being emitted
  * Add a 'removed_property' descriptor class
  * No need for Oslo Incubator Sync
  * docs - Set pbr 'warnerrors' option for doc build
  * Include changelog/history in docs
  * tweak language in readme
  * Enhance the README
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
  * Activate pep8 check that _ is imported
  * Add a moved function helper
* Wed Sep  9 2015 tbechtold@suse.com
- update to 0.8.0:
  * Updated from global requirements
* Tue Aug  4 2015 tbechtold@suse.com
- update to 0.7.0
  * Updated from global requirements
  * Expose a top level 'deprecate' function
  * Add @removals.removed_kwarg on an __init__ method
  * Improve + test keyword argument @classmethod removal
  * Add example for removing a @classmethod
* Tue Jul 28 2015 tbechtold@suse.com
- update to 0.6.0:
  * Ensure doctesting and doc8 testing done in py27 env
  * Updated from global requirements
  * Fix quoting of examples
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
* Tue Jun  2 2015 tbechtold@suse.com
- Adjust Require versions according to requirements.txt
* Tue Jun  2 2015 tbechtold@suse.com
- Initial packaging
